Search.setIndex({docnames:["fpq","index","modules"],envversion:53,filenames:["fpq.rst","index.rst","modules.rst"],objects:{"":{fpq:[0,0,0,"-"]},"fpq.fp":{decode_d3d_snorm_to_fp:[0,1,1,""],decode_ogl_snorm_to_fp:[0,1,1,""],decode_std_snorm_to_fp:[0,1,1,""],decode_std_unorm_to_fp:[0,1,1,""],decode_uint_to_fp:[0,1,1,""],encode_fp_to_d3d_snorm:[0,1,1,""],encode_fp_to_ogl_snorm:[0,1,1,""],encode_fp_to_std_snorm:[0,1,1,""],encode_fp_to_std_unorm:[0,1,1,""],encode_fp_to_uint:[0,1,1,""]},"fpq.numba_wrapper":{avoid_mapping_to_py_types:[0,1,1,""],avoid_non_supported_types:[0,1,1,""]},"fpq.quaternion":{decode_uint_to_quat:[0,1,1,""],encode_quat_to_uint:[0,1,1,""]},"fpq.utils":{get_max_component_indices:[0,1,1,""],remap:[0,1,1,""],remove_component:[0,1,1,""],rint:[0,1,1,""]},"fpq.vector":{calc_breakdown_of_uint:[0,1,1,""],decode_uint_to_vec:[0,1,1,""],encode_vec_to_uint:[0,1,1,""],is_valid_format:[0,1,1,""],l2norm:[0,1,1,""]},fpq:{fp:[0,0,0,"-"],numba_wrapper:[0,0,0,"-"],quaternion:[0,0,0,"-"],utils:[0,0,0,"-"],vector:[0,0,0,"-"]}},objnames:{"0":["py","module","Python module"],"1":["py","function","Python function"]},objtypes:{"0":"py:module","1":"py:function"},terms:{"class":0,"float":0,"function":0,"new":0,"return":0,The:0,arrai:0,autocast:[],avoid:0,avoid_mapping_to_py_typ:0,avoid_non_supported_typ:0,bit:0,bound:0,breakdown:0,calc_breakdown_of_uint:0,calcul:0,compon:0,content:2,convert:0,current:0,d3d:[],d3dfpq:[],dec:0,decod:0,decode_d3d_snorm_to_fp:0,decode_fp_from_snorm:[],decode_fp_from_unorm:[],decode_ogl_snorm_to_fp:0,decode_quat_from_uint32:[],decode_quat_from_uint:[],decode_snorm_to_fp:[],decode_std_snorm_to_fp:0,decode_std_unorm_to_fp:0,decode_uint_to_fp:0,decode_uint_to_quat:0,decode_uint_to_vec:0,decode_unorm_to_fp:[],dst:[],dst_max:0,dst_min:0,dtype:0,dtype_f:0,dtype_u:0,enc:0,encod:0,encode_fp_to_d3d_snorm:0,encode_fp_to_ogl_snorm:0,encode_fp_to_snorm:[],encode_fp_to_std_snorm:0,encode_fp_to_std_unorm:0,encode_fp_to_uint:0,encode_fp_to_unorm:[],encode_quat_to_uint32:[],encode_quat_to_uint:0,encode_vec_to_uint:0,exampl:0,exclud:0,float32:0,float64:0,four:0,from:0,gener:[],get:[],get_max_component_indic:0,incom:0,index:1,index_or_funct:[],indic:0,input:0,integ:0,is_valid_format:0,l2norm:0,lower:0,map:0,maximum:0,modul:[1,2],name_or_funct:0,nbit:0,non:0,none:0,norm:0,normal:0,numba_wrapp:2,number:0,numpi:0,packag:2,page:1,param:[],paramet:0,point:0,python:0,quaternion:2,rang:0,refer:0,remap:0,remov:0,remove_compon:0,remove_max_compon:[],repres:0,result:0,rint:0,search:1,should:0,sign:0,specifi:0,src:[],src_max:0,src_min:0,submodul:2,support:0,target:0,them:0,thi:0,three:0,type:0,uint16:0,uint32:[],uint64:0,uint8:0,uint:0,unsign:0,upper:0,use:0,util:2,valu:0,vector:2,version:[],wrapper:0},titles:["fpq package","Welcome to fpq\u2019s documentation!","fpq"],titleterms:{content:0,d3d:[],d3dfpq:[],document:1,fpq:[0,1,2],gener:[],indic:1,modul:0,numba_wrapp:0,packag:0,quaternion:0,submodul:0,tabl:1,util:0,vector:0,version:[],welcom:1}})